## 1.5.0.1 (2023-01-13)

Allowlist-only fixes for stubtest on Windows (#9522)

## 1.5.0 (2022-09-16)

[stubsabot] Bump tree-sitter-languages to 1.5.* (#8750)

Release: https://pypi.org/project/tree-sitter-languages/1.5.0/
Homepage: https://github.com/grantjenks/py-tree-sitter-languages
Diff: https://github.com/grantjenks/py-tree-sitter-languages/compare/v1.4.0...v1.5.0

## 1.4.0 (2022-08-26)

[stubsabot] Bump tree-sitter-languages to 1.4.* (#8623)

## 1.3.0 (2022-08-17)

Add stubs for tree-sitter-languages (#8548)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

